      SUBROUTINE sla__ATMS (RT, TT, DNT, GAMAL, R, DN, DNDR)
*+
*     - - - - -
*      A T M S
*     - - - - -
*
*  Internal routine used by REFRO
*
*  Refractive index and derivative wrt height for the stratosphere
*
*  Given:
*    RT      d    height of tropopause from centre of the Earth (metre)
*    TT      d    temperature at the tropopause (deg K)
*    DNT     d    refractive index at the tropopause
*    GAMAL   d    constant of the atmospheric model = G*MD/R
*    R       d    current distance from the centre of the Earth (metre)
*
*  Returned:
*    DN      d    refractive index at R
*    DNDR    d    rate the refractive index is changing at R
*
*  This routine is a version of the ATMOSSTR routine (C.Hohenkerk,
*  HMNAO), with trivial modifications.
*
*  Original version by C.Hohenkerk, HMNAO, August 1984
*  This Starlink version by P.T.Wallace, 4 July 1993
*-

      IMPLICIT NONE

      DOUBLE PRECISION RT,TT,DNT,GAMAL,R,DN,DNDR

      DOUBLE PRECISION B,W


      B = GAMAL/TT
      W = (DNT-1D0)*EXP(-B*(R-RT))
      DN = 1D0+W
      DNDR = -B*W

      END
