      subroutine cursor(x,y,key,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        cursor
C
C     Invocation:
C        call cursor(x,y,key,status)
C
C     Description:
C        Get a cursor keystroke and convert it to upper case.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!" Changed)
C        x:  Real (!)
C           X coordinate of the cursor. On entry it is the X coordinate
C           where the cursor is placed.  On exit it is the X coordinate
C           of the keystroke.
C        y:  Real (!)
C           Y coordinate of the cursor. On entry it is the Y coordinate
C           where the cursor is placed.  On exit it is the Y coordinate
C           of the keystroke.
C        key:  Character (>)
C           Value of keystroke 
C        status: Integer (!)
C           Status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        Library chr:
C           chr_upper
C
C        Library pgplot:
C           pgcurs
C
C     External routines called:
C        none
C 
C     Algorithm:
C        -- A cursor keystroke is obtained from PGPLOT.  If PGPLOT returns
C           bad status, then we escape with bad status.
C        -- Change the keystroke to upper case.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      real x
      real y
      character key*(*)
      integer status
C
C     Functions
C
      integer pgcurs
      character chr_upper*1
C
C     Inherited status
C 
      if (status .ne. af2_ok) go to 500
C
C     Get a cursor point
C
      if (pgcurs(x,y,key) .ne. 1) then
         status = af2_err
         go to 500
      end if
C
C     Change the key to upper case
C
      key = chr_upper(key)
C
C     Exit
C
  500 continue
      end
