      subroutine draw_fibres(piv,fib,npivots,fibdims,fibstatus,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        draw_fibres
C
C     Invocation:
C        call draw_fibres(piv,fib,npivits,fibdims,fibstatus,status)
C
C     Description:
C        The fibre tubes and buttons are drawn on the current PGPLOT
C        device.  The colour of the fibre will vary depending upon
C        the fibre status (object, fiducial, disabled, etc).
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        piv:  Integer array (>)
C           The coordinates of the all of the pivots.
C        fib:  Integer array (>)
C           The coordinates of all of the fibre buttons
C        npivots:  Integer (>)
C           The number of pivots
C        fibdims:  Integer array (>)
C           The dimensions of the fibres: 1 -- button length, 2 -- button
C           width, 3 -- tube width
C        fibstatus:  Integer array (>)
C           Array of values which gives the fibre type for each pivot
C           (i.e. fiducial, object, disabled, etc).
C        status:  Integer (!)
C           Global status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library subaf2_configure:
C           calc_rects
C           normfibre
C
C        Library pgplot:
C           pgbbuf
C           pgebuf
C           pgsci
C 
C     Algorithm:
C        -- The PGPLOT calls are buffered for speed
C        -- The status of each fibre is checked in turn.  So long
C           as the fibre isn't missing, then the fibre tube and button
C           will be plotted as two filled rectangles.
C        -- The colour of the fibre on the plot will vary according to
C           the fibre status and is decided in the routine 'normfibre'.
C        -- The PGPLOT colour index is returned to the drawing colour
C           before exit.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_PAR.INC'
      include 'AF2_FSTA.INC'
C
C     Parameters
C
      integer npivots
      integer piv(2,npivots)
      integer fib(2,npivots)
      integer fibdims(3)
      integer fibstatus(npivots)
      integer status
C
C     Local variables
C
      real piv1(2),but1(2),button(8),tube(8)
      integer k
C
C     Inherited status
C
      if (status .ne. af2_ok) go to 500
C
C     Buffer the PGPLOT calls
C 
      call pgbbuf
C
C     Loop for the pivots and draw a fibre of the appropriate colour
C
      do 10 k = 1, npivots
         if (fibstatus(k) .ne. fsta_miss) then
            piv1(1) = real(piv(1,k))
            piv1(2) = real(piv(2,k))
            but1(1) = real(fib(1,k))
            but1(2) = real(fib(2,k))
            call calc_rects(piv1,but1,fibdims,button,tube)
            call normfibre(button,tube,fibstatus(k))
         end if
 10   continue
C
C     Return the colour index to the drawing colour
C
      call pgsci(1)
C
C     End the PGPLOT buffering
C
      call pgebuf
C
C     Exit
C
  500 continue
      end
