      subroutine fibre_check(pivot1,fibre1,pivot2,fibre2,fibdims,
     :   fstatus)
C+------------------------------------------------------------------------------
C
C     Name:   
C        fibre_check
C
C     Invocation:
C        call fibre_check(pivot1,fibre1,pivot2,fibre2,fibdims,fstatus)
C
C     Description:
C        Two fibres are checked to see if there is a collision between them
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        pivot1:  Real array (>)
C           The x,y coordinates of the pivot for the first fibre
C        fibre1:  Real array(>)
C           The x,y coordinates of the button for the first fibre
C        pivot2:  Real array (>)
C           The x,y coordinates of the pivot for the second fibre
C        fibre2:  Real array(>)
C           The x,y coordinates of the button for the second fibre
C        fibdims:  Integer array (>)
C           The dimensions of the fibres: 1 -- button length, 2 -- button
C           width, 3 -- tube width
C        fstatus:  Integer (<)
C           Status variable which tells whether there has been a collision
C           or not and if so, what type.  This is assigned values from the
C           include file 'af2_fchk.inc'.
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library subaf2_configure:
C           calc_rects
C           line_cross
C           rect_check
C 
C     Algorithm:
C        -- Start out by assuming a good status
C        -- The tubes are first checked to see whether they cross. If
C           they do, then exit with bad status.
C        -- The corners of the fibre tubes and buttons are calculated
C        -- The tubes and buttons of the fibres are checked to see if 
C           there is any overlap.  They are checked in the following order:
C           button1 vs. button2, button1 vs. tube2, button2 vs. tube1.
C           The routine exits with a bad status the first time any of these
C           fail.
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C
      include 'AF2_FCHK.INC'
C
C     Parameters
C
      real pivot1(2)
      real fibre1(2)
      real pivot2(2)
      real fibre2(2)
      integer fibdims(3)
      integer fstatus
C
C     Local variables
C
      logical crossed
      real button1(8),button2(8),tube1(8),tube2(8)
C    
C     Functions
C
      logical rect_check,line_cross
C
C     Initialise the local status variable
C
      fstatus = fchk_ok
C
C     First check the lines defined by the pivots and the objects and 
C     see if the two lines cross.  If they do, then leave here immediately
C     with an error status
C
      crossed = line_cross(pivot1,fibre1,pivot2,fibre2)
      if (crossed) then
         fstatus = fchk_lines
         go to 500
      end if
C
C     Now calculate the limits of the buttons and tubes
C
      call calc_rects(pivot1,fibre1,fibdims,button1,tube1)
      call calc_rects(pivot2,fibre2,fibdims,button2,tube2)
C
C     Check that the buttons don't overlap
C
      if (rect_check(button1,button2)) then
         fstatus = fchk_buttons
         go to 500
      end if
C
C     Now check that tube2 doesn't hit button1
C
      if (rect_check(button1,tube2)) then
         fstatus = fchk_b1t2
         go to 500
      end if
C
C     Now check that tube1 doesn't hit button2
C
      if (rect_check(button2,tube1)) then 
         fstatus = fchk_b2t1
         go to 500
      end if
C
C     Exit
C
  500 continue
      end 
