      subroutine mkmessage(curfib,offender,fstatus,message,lenm,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        mkmessage
C
C     Invocation:
C        call mkmessage(curfib,offender,fstatus,message,lenm,status)
C
C     Description:
C        Interpret the fibre collision status variable and create 
C        an appropriate error message from it.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        curfib:  Integer (>)
C           The pivot number of the current fibre.
C        offender:  Integer (>)
C           The pivot number of the offending fibre.
C        fstatus:  Integer (>)
C           Status variable which tells whether there has been a collision
C           or not and if so, what type.  This is assigned values from the
C           include file 'af2_fchk.inc'.
C        message:  Character (<)
C           The output error message
C        lenm:  integer (<)
C           The location of the last non-blank character in the message string
C        status:  Integer (!)
C           The global status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library chr:
C           chr_len
C 
C     Algorithm:
C        -- If the collision status is good, then set a blank message and
C           leave.
C        -- Test for each of the standard collision status values and format
C           an error message accordingly
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Global parameters
C  
      include 'AF2_PAR.INC'
      include 'AF2_FCHK.INC'
C
C     Parameters
C
      integer curfib
      integer offender
      integer fstatus
      character message*(*)
      integer lenm
      integer status
C
C     Functions
C
      integer chr_len
C
C     Inherited status
C
      if (status .ne. af2_ok) go to 500
C
C     If the fibre status is ok, then leave
C
      if (fstatus .eq. fchk_ok) then
         message = ' '
         lenm = 0
         go to 500
      end if
C
C     Otherwise write an appropriate error message depending on the offence. 
C
C     The tubes hit each other
C
      if (fstatus .eq. fchk_tubes) then
         write(message,fmt='(a,i3,a,i3)') 'Tube ',curfib,
     :      ' hits tube ',offender
C
C     The current fibre's tube hits the offender's button
C
      else if (fstatus .eq. fchk_b2t1) then
         write(message,fmt='(a,i3,a,i3)') 'Tube ',curfib,
     :      ' hits button ',offender
C
C     The current fibre's button hits the offender's tube
C
      else if (fstatus .eq. fchk_b1t2) then
         write(message,fmt='(a,i3,a,i3)') 'Button ',curfib,
     :      ' hits tube ',offender
C
C     The two buttons hit
C
      else if (fstatus .eq. fchk_buttons) then
         write(message,fmt='(a,i3,a,i3)') 'Button ',curfib,
     :      ' hits button ',offender
C
C     The two lines cross
C
      else if (fstatus .eq. fchk_lines) then
         write(message,fmt='(a,i3,a,i3)') 'Tube ',curfib,
     :      ' crosses tube ',offender
C
C     The current fibre can't reach because it's too short
C
      else if (fstatus .eq. fchk_reach) then
         write(message,fmt='(a,i3,a)') 'Fibre ',curfib,
     :      ' can''t reach that far'
C
C     The nonradial angle of the current fibre is too great
C
      else if (fstatus .eq. fchk_maxang) then
         write(message,fmt='(a,i3)') 
     :      'Object is at too great an angle for fibre ',curfib
C
C     Non-standard status
C
      else
         write(message,fmt='(a)') 'Non-standard error code!'
      end if
C
C     Get the length of the output error message
C
      lenm = chr_len(message)
C
C     Exit
C
  500 continue
      end
