      subroutine opnewfile(name,extn,fd,usever,status)
C+------------------------------------------------------------------------------
C
C     Name:   
C        opnewfile
C
C     Invocation:
C        call opnewfile(name,extn,fd,usever,status)
C
C     Description:
C        A new sequential access file with a given name and extension is 
C        opened.  The option exists to append a version number.
C
C     Arguments: (">" Input, "<" Output, "W" Workspace, "!"  Changed)
C        name:  Character (>)
C           The name of the new file
C        extn:  Character (>)
C           The file name extension (without the leading dot).
C        fd:  Integer (>)
C           The logical unit number for the new file
C        usever:  Logical (>)
C           TRUE if a version number is desired.
C        status:  Integer (!)
C           The global status variable
C
C     Language:
C        FORTRAN 77
C
C     Non-standard language extensions:
C        include, implicit none, do while, variable names > 6 characters
C
C     Logical i/o units used:
C        none
C
C     External routines called:
C        Library chr:
C           chr_len
C           chr_puti
C 
C     Algorithm:
C        -- The base name is formed by concatinating the file name and 
C           the extension with a dot in between.
C        -- If the user wants a version number, then start at the maximum
C           allowable version number (maxver) and work backwards until we
C           find a file with that version number.  Append a dot to the base
C           name and add the new version number.
C        -- The file is opened with access='sequential'
C
C     Authors:
C        (JRL): James R. Lewis -- RGO, Cambridge
C
C     History:
C        01 Dec 1995 (JRL):
C           Original version
C
C-------------------------------------------------------------------------------
      implicit none
C
C     Include files
C
      include 'AF2_PAR.INC'
C
C     Parameters
C
      character name*(*)
      character extn*(*)
      integer fd
      logical usever
      integer status
C
C     Local variables
C
      integer len1,len2,ver,iostat
      character fname*80,testname*80
      logical breakout
C
C     Functions
C
      integer chr_len
C
C     Inherited status
C
      if (status .ne. af2_ok) go to 500
C
C     Form a base name from the file name and its extension.  If the file
C     name has no size, then call that an error.  If the extension has no
C     length, then don't worry.
C
      len1 = chr_len(name)
      if (len1 .eq. 0) then
         write(*,fmt='(a)') 
     :      'New file name has no length -- programming error'
         status = af2_err
         go to 500
      end if
      len2 = chr_len(extn)
      fname = name(:len1)//'.'
      if (len2 .ne. 0) fname = fname(:len1+1)//extn(:len2)
      len1 = chr_len(fname)
C
C     Now, find a version which doesn't exist.  Go backwards from
C     the highest allowable version number until you find a version
C     which exists.  Signal an error if you already have a file
C     with the maximum version number.
C
      if (usever) then
         ver = maxver + 1
         breakout = .false.
         do while (.not. breakout)
            ver = ver - 1
            if (ver .eq. 0) then
               breakout = .true.
            else 
               testname = fname(:len1)//'.'
               len2 = len1 + 1
               call chr_puti(ver,testname,len2)
               inquire(file=testname(:len2),exist=breakout)
            end if
         end do
         ver = ver + 1
         if (ver .ge. maxver) then
            write(*,fmt='(a,a)') 'Maximum version number exceeded for ',
     :         fname(:len1-1)
            status = af2_err
            go to 500
         end if
C
C        Put the version number onto the file name
C
         fname = fname(:len1)//'.'
         len1 = len1 + 1
         call chr_puti(ver,fname,len1)
      end if
C
C     Finally open the file as a new sequential access file
C
      open(unit=fd,file=fname(:len1),status='new',access='sequential',
     :   iostat=iostat)
      if (iostat .ne. 0) then
         status = af2_err
         write(*,fmt='(a,a)') 'Error opening file :',fname(:len1)
      end if
C
C     Exit
C
  500 continue
      end
